@@ -156,6 +156,21 @@ class Bowtie2(object):
                 '-n ' if byName else '', inFile, sortedFile))
         self._executor.execute("mv '%s' '%s'" % (sortedFile, inFile))
 
+    def removePrimers(self, bedFile):
+        """
+        Removes primers specified in the bed file
+        """
+        which = self._SAMorBAM()
+
+        if which != 'BAM':
+            raise ValueError('makeBAM() has not yet been called.')
+
+        self._report("removing primers specified in %s" % bedFile)
+        self._executor.execute(
+            "ivar trim -b %s -p result-trimmed -i %s -q 20 -m 30 -s 4 -e" %
+            (bedFile, self._bamFile))
+        self._executor.execute("mv result-trimmed.bam '%s'" % self._bamFile)
+
     def markDuplicatesPicard(self, picardFile):
         """
         Use Picard to mark duplicates.
@@ -235,6 +250,7 @@ class Bowtie2(object):
             "--reference '%s' "
             "--input '%s' "
             "--output '%s' "
+            "--sample-ploidy 1 "
             '-ERC GVCF' %
             (referenceFasta, inFile, vcfFile))
 
@@ -244,6 +260,31 @@ class Bowtie2(object):
         if removeDict:
             self._executor.execute("rm '%s'" % dictFile)
 
+    def callHaplotypesBcftools(self, vcfFile=None, referenceFasta=None):
+        """
+        Use bcftools call to call haplotypes.
+        """
+        which = self._SAMorBAM()
+        self._report('Calling haplotypes with bcftools call.')
+
+        inFile = self._bamFile if which == 'BAM' else self._samFile
+        vcfFile = vcfFile or join(self.tempdir, 'output.vcf.gz')
+
+        if referenceFasta is None:
+            if self._reference:
+                self._report('Using %s as a reference.' % self._reference)
+                referenceFasta = self._reference
+            else:
+                raise ValueError('No reference was passed, given to the '
+                                 'Bowtie2 __init__, or used in buildIndex.')
+
+        self._executor.execute(
+            'bcftools mpileup --max-depth 5000 -Ou -f "%s" "%s" | '
+            'bcftools call --ploidy 1 -mv -Oz -o "%s"' %
+            (referenceFasta, inFile, vcfFile))
+
+        self._executor.execute('bcftools index %s' % vcfFile)
+
     def removeDuplicates(self):
         """
         Use samtools to remove marked duplicates.
